import React from 'react';
import { Animated } from 'react-native';
import { IconAnimationRegistry } from './iconAnimation';
interface ComponentProps {
    name: string;
    pack?: string;
    animation?: keyof IconAnimationRegistry;
}
export declare type IconProps<T = {}> = ComponentProps & T;
export declare type IconElement<T> = React.ReactElement<T>;
/**
 * Icon component with animation support. Allows to render any ReactElement registered for a specific name.
 * Starting from UI Kitten 4.2, there is `@ui-kitten/eva-icons` module
 * that renders any icon from eva-icons package in `svg` format.
 *
 * @extends React.Component
 *
 * @method {(callback?: Animated.EndCallback) => void} startAnimation - Toggle animation to start.
 * @method {() => void} stopAnimation - Toggle animation to stop.
 * @property {string} name - Name of registered icon.
 * @property {string} pack - Name of icon pack that is able to provide an icon for specified name.
 * @property {string} animation - Animation name. Available `zoom`, `pulse` and `shake`. Default is `zoom`.
 *
 * @overview-example Register Icons
 *
 * ```
 * import React from 'react';
 * import { mapping, light as lightTheme } from '@eva-design/eva';
 * import { ApplicationProvider, IconRegistry } from '../..';
 * import { EvaIconsPack } from '../../../eva-icons'; // <-- Make sure it is installed. npm i @ui-kitten/eva-icons
 * import { Application } from './path-to/root.component';
 *
 * export default class App extends React.Component {
 *
 *   public render(): React.ReactNode {
 *     return (
 *       <ApplicationProvider
 *         mapping={mapping}
 *         theme={lightTheme}>
 *         <Application/>
 *         <IconRegistry icons={EvaIconsPack}/>
 *       </ApplicationProvider>
 *     );
 *   }
 * }
 * ```
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { Icon } from '../..';
 *
 * export const StarIcon = (props) => (
 *   <Icon name='star'/>
 * );
 * ```
 *
 * @overview-example Animation Usage
 *
 * ```
 * import React from 'react';
 * import { Icon } from '../..';
 *
 * const iconRef = React.createRef();
 *
 * export const StarIcon = (props) => (
 *   <Icon ref={iconRef} name='star' animation='shake'/>
 * );
 *
 * iconRef.current.startAnimation();
 * ```
 *
 * @example Password Input
 *
 * ```
 * import React from 'react';
 * import { Input, Icon } from '../..';
 *
 * export class PasswordInput extends React.Component {
 *  state = {
 *    passwordVisible: false,
 *  };
 *
 *  onPasswordIconPress = () => {
 *    const passwordVisible = !this.state.passwordVisible;
 *    this.setState({ passwordVisible });
 *  };
 *
 *  renderPasswordIcon = (style) => (
 *    <Icon
 *      name={this.state.passwordVisible ? 'eye' : 'eye-off'}
 *      {...style}
 *    />
 *  );
 *
 *  render() {
 *    return (
 *      <Input
 *        icon={this.renderPasswordIcon}
 *        onIconPress={this.onPasswordIconPress}
 *        secureTextEntry={!this.state.passwordVisible}
 *      />
 *    );
 *  }
 * }
 * ```
 *
 * @example Like Button
 *
 * ```
 * import React from 'react';
 * import { Button, Icon } from '../..';
 *
 * export class LikeButton extends React.Component {
 *  state = {
 *    liked: false,
 *  };
 *
 *  onPress = () => {
 *    const liked = !this.state.liked;
 *    this.setState({ liked });
 *  };
 *
 *  renderHeartIcon = (style) => (
 *    <Icon
 *      name={this.state.liked ? 'heart' : 'heart-outline'}
 *      {...style}
 *    />
 *  );
 *
 *  render() {
 *    return (
 *      <Button
 *        icon={this.renderHeartIcon}
 *        onPress={this.onPress}
 *      />
 *    );
 *  }
 * }
 * ```
 */
export declare class Icon<T> extends React.Component<IconProps<T>> {
    static defaultProps: Partial<IconProps>;
    private readonly animation;
    constructor(props: IconProps<T>);
    componentWillUnmount(): void;
    startAnimation: (callback?: Animated.EndCallback) => void;
    stopAnimation: () => void;
    private getComponentStyle;
    render(): React.ReactElement<T>;
}
export {};
